@@ -66,7 +66,7 @@
                 }
               }
               or croak "Type check failed in constructor: %s should be %s",
-              "attributes", "HashRef[InstanceOf[\"Mite::Attribute\"]]";
+              "attributes", "HashRef[Mite::Attribute]";
             $self->{"attributes"} = $value;
         };
 
@@ -82,10 +82,16 @@
                           or ref( \( my $val = $args->{"name"} ) ) eq 'SCALAR';
                     }
                 }
-            ) && do { package Mite::Shim; length( $args->{"name"} ) > 0 }
+            )
+              && (
+                do {
+                    local $_ = $args->{"name"};
+                    /\A[^\W0-9]\w*(?:::[^\W0-9]\w*)*\z/;
+                }
+              )
           )
           or croak "Type check failed in constructor: %s should be %s", "name",
-          "NonEmptyStr";
+          "ValidClassName";
         $self->{"name"} = $args->{"name"};
 
         # Attribute: shim_name
@@ -102,10 +108,15 @@
                         }
                     }
                 )
-                  && do { package Mite::Shim; length( $args->{"shim_name"} ) > 0 }
+                  && (
+                    do {
+                        local $_ = $args->{"shim_name"};
+                        /\A[^\W0-9]\w*(?:::[^\W0-9]\w*)*\z/;
+                    }
+                  )
               )
               or croak "Type check failed in constructor: %s should be %s",
-              "shim_name", "NonEmptyStr";
+              "shim_name", "ValidClassName";
             $self->{"shim_name"} = $args->{"shim_name"};
         }
 
@@ -119,7 +130,7 @@
                 }
               )
               or croak "Type check failed in constructor: %s should be %s",
-              "source", "InstanceOf[\"Mite::Source\"]";
+              "source", "Mite::Source";
             $self->{"source"} = $args->{"source"};
         }
         require Scalar::Util && Scalar::Util::weaken( $self->{"source"} )
@@ -140,10 +151,9 @@
                         ( $ok = 0, last )
                           unless (
                             do {
-
-                                package Mite::Shim;
                                 use Scalar::Util ();
-                                Scalar::Util::blessed($i);
+                                Scalar::Util::blessed($i)
+                                  and $i->isa(q[Mite::Role]);
                             }
                           );
                     };
@@ -151,7 +161,7 @@
                 }
               }
               or croak "Type check failed in constructor: %s should be %s",
-              "roles", "ArrayRef[Object]";
+              "roles", "ArrayRef[Mite::Role]";
             $self->{"roles"} = $value;
         };
 
@@ -166,28 +176,38 @@
                 package Mite::Shim;
                 ( ref($value) eq 'HASH' ) and do {
                     my $ok = 1;
-                    for my $i ( values %{$value} ) {
+                    for my $v ( values %{$value} ) {
+                        ( $ok = 0, last ) unless do {
+
+                            package Mite::Shim;
+                            defined($v) and do {
+                                ref( \$v ) eq 'SCALAR'
+                                  or ref( \( my $val = $v ) ) eq 'SCALAR';
+                            }
+                        }
+                    };
+                    for my $k ( keys %{$value} ) {
                         ( $ok = 0, last )
                           unless (
                             (
                                 do {
 
                                     package Mite::Shim;
-                                    defined($i) and do {
-                                        ref( \$i ) eq 'SCALAR'
-                                          or ref( \( my $val = $i ) ) eq
+                                    defined($k) and do {
+                                        ref( \$k ) eq 'SCALAR'
+                                          or ref( \( my $val = $k ) ) eq
                                           'SCALAR';
                                     }
                                 }
                             )
-                            && ( length($i) > 0 )
+                            && ( do { local $_ = $k; /\A[^\W0-9]\w*\z/ } )
                           );
                     };
                     $ok;
                 }
               }
               or croak "Type check failed in constructor: %s should be %s",
-              "imported_functions", "HashRef[NonEmptyStr]";
+              "imported_functions", "Map[MethodName,Str]";
             $self->{"imported_functions"} = $value;
         };
 
@@ -216,14 +236,14 @@
                                     }
                                 }
                             )
-                            && ( length($i) > 0 )
+                            && ( do { local $_ = $i; /\A[^\W0-9]\w*\z/ } )
                           );
                     };
                     $ok;
                 }
               }
               or croak "Type check failed in constructor: %s should be %s",
-              "required_methods", "ArrayRef[NonEmptyStr]";
+              "required_methods", "ArrayRef[MethodName]";
             $self->{"required_methods"} = $value;
         };
 
@@ -252,14 +272,19 @@
                                     }
                                 }
                             )
-                            && ( length($i) > 0 )
+                            && (
+                                do {
+                                    local $_ = $i;
+                                    /\A[^\W0-9]\w*(?:::[^\W0-9]\w*)*\z/;
+                                }
+                            )
                           );
                     };
                     $ok;
                 }
               }
               or croak "Type check failed in constructor: %s should be %s",
-              "extends", "ArrayRef[NonEmptyStr]";
+              "extends", "ArrayRef[ValidClassName]";
             $self->{"extends"} = $value;
         };
 
@@ -283,7 +308,7 @@
                 }
               )
               or croak "Type check failed in constructor: %s should be %s",
-              "parents", "ArrayRef[InstanceOf[\"Mite::Class\"]]";
+              "parents", "ArrayRef[Mite::Class]";
             $self->{"parents"} = $args->{"parents"};
         }
 
@@ -387,14 +412,19 @@
                                     }
                                 }
                             )
-                            && ( length($i) > 0 )
+                            && (
+                                do {
+                                    local $_ = $i;
+                                    /\A[^\W0-9]\w*(?:::[^\W0-9]\w*)*\z/;
+                                }
+                            )
                           );
                     };
                     $ok;
                 }
               }
               or croak( "Type check failed in %s: value should be %s",
-                "accessor", "ArrayRef[NonEmptyStr]" );
+                "accessor", "ArrayRef[ValidClassName]" );
             $_[0]{"extends"} = $_[1];
             $_[0]->_trigger_extends( $_[0]{"extends"}, @oldvalue );
             $_[0];
@@ -430,11 +460,8 @@
                             $ok;
                         }
                       }
-                      or croak(
-                        "Type check failed in default: %s should be %s",
-                        "parents",
-                        "ArrayRef[InstanceOf[\"Mite::Class\"]]"
-                      );
+                      or croak( "Type check failed in default: %s should be %s",
+                        "parents", "ArrayRef[Mite::Class]" );
                     $default_value;
                 }
             )
