@@ -6,7 +6,7 @@ package Mite::Compiled;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006008';
+our $VERSION   = '0.006009';
 
 use Path::Tiny;
 
@@ -24,7 +24,7 @@ has file =>
 
 has source =>
   is            => ro,
-  isa           => InstanceOf['Mite::Source'],
+  isa           => MiteSource,
   # avoid a circular dep with Mite::Source
   weak_ref      => true,
   required      => true;
