@@ -5,10 +5,11 @@ use warnings;
 package Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006008';
+our $VERSION   = '0.006009';
 
 use Import::Into;
 use Mite::Shim ();
+use Mite::Types ();
 use Types::Standard ();
 use Types::Common::String ();
 use Types::Path::Tiny ();
@@ -47,6 +48,9 @@ sub to_import {
 	my ( $class, $arg ) = ( shift, @_ );
 	no warnings 'uninitialized';
 	return (
+		[ 'Mite::Types' => [
+			qw( -types ),
+		] ],
 		[ 'Types::Standard' => [
 			qw( -types slurpy ),
 		] ],
