@@ -6,16 +6,16 @@ package Mite::Project;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006008';
+our $VERSION   = '0.006009';
 
 has sources =>
   is            => ro,
-  isa           => HashRef[InstanceOf['Mite::Source']],
+  isa           => HashRef[MiteSource],
   default       => sub { {} };
 
 has config =>
   is            => ro,
-  isa           => InstanceOf['Mite::Config'],
+  isa           => MiteConfig,
   lazy          => 1,
   default       => sub {
       require Mite::Config;
